/*
 Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("specialchar","ku",{euro:"نیشانه‌ی یۆرۆ",lsquo:"نیشانه‌ی فاریزه‌ی سه‌رووژێری تاکی چه‌پ",rsquo:"نیشانه‌ی فاریزه‌ی سه‌رووژێری تاکی ڕاست",ldquo:"نیشانه‌ی فاریزه‌ی سه‌رووژێری دووهێنده‌ی چه‌پ",rdquo:"نیشانه‌ی فاریزه‌ی سه‌رووژێری دووهێنده‌ی ڕاست",ndash:"ته‌قه‌ڵی کورت",mdash:"ته‌قه‌ڵی درێژ",iexcl:"نیشانه‌ی هه‌ڵه‌وگێڕی سه‌رسوڕمێنه‌ر",cent:"نیشانه‌ی سه‌نت",pound:"نیشانه‌ی پاوه‌ند",curren:"نیشانه‌ی دراو",yen:"نیشانه‌ی یه‌نی ژاپۆنی",brvbar:"شریتی ئه‌ستوونی پچڕاو",sect:"نیشانه‌ی دوو s له‌سه‌ریه‌ك",
uml:"خاڵ",copy:"نیشانه‌ی مافی چاپ",ordf:"هێڵ له‌سه‌ر پیتی a",laquo:"دوو تیری به‌دووایه‌کی چه‌پ",not:"نیشانه‌ی نه‌خێر",reg:"نیشانه‌ی R له‌ناو بازنه‌دا",macr:"ماکڕوون",deg:"نیشانه‌ی پله",sup2:"سه‌رنووسی دوو",sup3:"سه‌رنووسی سێ",acute:"لاری تیژ",micro:"نیشانه‌ی u لق درێژی چه‌پی خواروو",para:"نیشانه‌یپه‌ڕه‌گراف",middot:"ناوه‌ڕاستی خاڵ",cedil:"نیشانه‌ی c ژێر چووکره‌",sup1:"سه‌رنووسی یه‌ك",ordm:"هێڵ له‌ژێر پیتی o",raquo:"دوو تیری به‌دووایه‌کی ڕاست",frac14:"یه‌ك له‌سه‌ر چووار",frac12:"یه‌ك له‌سه‌ر دوو",
frac34:"سێ له‌سه‌ر چووار",iquest:"هێمای هه‌ڵه‌وگێری پرسیار",Agrave:"پیتی لاتینی A-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری لار",Aacute:"پیتی لاتینی A-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری تیژ",Acirc:"پیتی لاتینی A-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",Atilde:"پیتی لاتینی A-ی گه‌وره‌ له‌گه‌ڵ زه‌ڕه‌",Auml:"پیتی لاتینی A-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",Aring:"پیتی لاتینی گه‌وره‌ی Å",AElig:"پیتی لاتینی گه‌وره‌ی Æ",Ccedil:"پیتی لاتینی C-ی گه‌وره‌ له‌گه‌ڵ ژێر چووکره‌",Egrave:"پیتی لاتینی E-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری لار",
Eacute:"پیتی لاتینی E-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری تیژ",Ecirc:"پیتی لاتینی E-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",Euml:"پیتی لاتینی E-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",Igrave:"پیتی لاتینی I-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری لار",Iacute:"پیتی لاتینی I-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری تیژ",Icirc:"پیتی لاتینی I-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",Iuml:"پیتی لاتینی I-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",ETH:"پیتی لاتینی E-ی گه‌وره‌ی",Ntilde:"پیتی لاتینی N-ی گه‌وره‌ له‌گه‌ڵ زه‌ڕه‌",Ograve:"پیتی لاتینی O-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری لار",
Oacute:"پیتی لاتینی O-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری تیژ",Ocirc:"پیتی لاتینی O-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",Otilde:"پیتی لاتینی O-ی گه‌وره‌ له‌گه‌ڵ زه‌ڕه‌",Ouml:"پیتی لاتینی O-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",times:"نیشانه‌ی لێکدان",Oslash:"پیتی لاتینی گه‌وره‌ی Ø له‌گه‌ڵ هێمای دڵ وه‌ستان",Ugrave:"پیتی لاتینی U-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری لار",Uacute:"پیتی لاتینی U-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری تیژ",Ucirc:"پیتی لاتینی U-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",Uuml:"پیتی لاتینی U-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",
Yacute:"پیتی لاتینی Y-ی گه‌وره‌ له‌گه‌ڵ ڕوومه‌تداری تیژ",THORN:"پیتی لاتینی دڕکی گه‌وره",szlig:"پیتی لاتنی نووك تیژی s",agrave:"پیتی لاتینی a-ی بچووك له‌گه‌ڵ ڕوومه‌تداری لار",aacute:"پیتی لاتینی a-ی بچووك له‌گه‌ڵ ڕوومه‌تداری تیژ",acirc:"پیتی لاتینی a-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",atilde:"پیتی لاتینی a-ی بچووك له‌گه‌ڵ زه‌ڕه‌",auml:"پیتی لاتینی a-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",aring:"پیتی لاتینی å-ی بچووك",aelig:"پیتی لاتینی æ-ی بچووك",ccedil:"پیتی لاتینی c-ی بچووك له‌گه‌ڵ ژێر چووکره‌",egrave:"پیتی لاتینی e-ی بچووك له‌گه‌ڵ ڕوومه‌تداری لار",
eacute:"پیتی لاتینی e-ی بچووك له‌گه‌ڵ ڕوومه‌تداری تیژ",ecirc:"پیتی لاتینی e-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",euml:"پیتی لاتینی e-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",igrave:"پیتی لاتینی i-ی بچووك له‌گه‌ڵ ڕوومه‌تداری لار",iacute:"پیتی لاتینی i-ی بچووك له‌گه‌ڵ ڕوومه‌تداری تیژ",icirc:"پیتی لاتینی i-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",iuml:"پیتی لاتینی i-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",eth:"پیتی لاتینی e-ی بچووك",ntilde:"پیتی لاتینی n-ی بچووك له‌گه‌ڵ زه‌ڕه‌",ograve:"پیتی لاتینی o-ی بچووك له‌گه‌ڵ ڕوومه‌تداری لار",
oacute:"پیتی لاتینی o-ی بچووك له‌گه‌ڵ ڕوومه‌تداری تیژ",ocirc:"پیتی لاتینی o-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",otilde:"پیتی لاتینی o-ی بچووك له‌گه‌ڵ زه‌ڕه‌",ouml:"پیتی لاتینی o-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",divide:"نیشانه‌ی دابه‌ش",oslash:"پیتی لاتینی گه‌وره‌ی ø له‌گه‌ڵ هێمای دڵ وه‌ستان",ugrave:"پیتی لاتینی u-ی بچووك له‌گه‌ڵ ڕوومه‌تداری لار",uacute:"پیتی لاتینی u-ی بچووك له‌گه‌ڵ ڕوومه‌تداری تیژ",ucirc:"پیتی لاتینی u-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",uuml:"پیتی لاتینی u-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",
yacute:"پیتی لاتینی y-ی بچووك له‌گه‌ڵ ڕوومه‌تداری تیژ",thorn:"پیتی لاتینی دڕکی بچووك",yuml:"پیتی لاتینی y-ی بچووك له‌گه‌ڵ نیشانه‌ له‌سه‌ری",OElig:"پیتی لاتینی گه‌وره‌ی پێکه‌وه‌نووسراوی OE",oelig:"پیتی لاتینی بچووکی پێکه‌وه‌نووسراوی oe",372:"پیتی لاتینی W-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",374:"پیتی لاتینی Y-ی گه‌وره‌ له‌گه‌ڵ نیشانه‌ له‌سه‌ری",373:"پیتی لاتینی w-ی بچووکی له‌گه‌ڵ نیشانه‌ له‌سه‌ری",375:"پیتی لاتینی y-ی بچووکی له‌گه‌ڵ نیشانه‌ له‌سه‌ری",sbquo:"نیشانه‌ی فاریزه‌ی نزم",8219:"نیشانه‌ی فاریزه‌ی به‌رزی پێچه‌وانه",
bdquo:"دوو فاریزه‌ی ته‌نیش یه‌ك",hellip:"ئاسۆیی بازنه",trade:"نیشانه‌ی بازرگانی",9658:"ئاراسته‌ی ڕه‌شی ده‌ستی ڕاست",bull:"فیشه‌ك",rarr:"تیری ده‌ستی ڕاست",rArr:"دووتیری ده‌ستی ڕاست",hArr:"دوو تیری ڕاست و چه‌پ",diams:"ڕه‌شی پاقڵاوه‌یی",asymp:"نیشانه‌ی یه‌کسانه"});