/*
 Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
*/
CKEDITOR.dialog.add("myDialog",function(){return{title:"My Dialog",minWidth:400,minHeight:200,contents:[{id:"tab1",label:"First Tab",title:"First Tab",elements:[{id:"input1",type:"text",label:"Text Field"},{id:"select1",type:"select",label:"Select Field",items:[["option1","value1"],["option2","value2"]]}]},{id:"tab2",label:"Second Tab",title:"Second Tab",elements:[{id:"button1",type:"button",label:"Button Field"}]}]}});